pub struct AnalysisParts {
pub graph: CodeGraph,
pub scc: SccAnalysis,
pub scope: FlattenedScopeCache,
pub references: Vec<ResolvedReference>,
}Expand description
Everything one analysis pass produces from a set of extractions.
Fields
graph: CodeGraphscc: SccAnalysisscope: FlattenedScopeCacheFlattened scope cache used to resolve a name from a cursor position.
references: Vec<ResolvedReference>One record per resolved use site, in extraction and reference order.