#[non_exhaustive]pub enum EdgeKind {
Ownership,
Import,
Reference,
Flow,
}Expand description
Semantic kind of a directed edge in the code graph.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ownership
Ownership edge: File owns/contains a symbol.
Import
Import edge: File imports/depends on another file.
Reference
Reference edge: Symbol references/uses another symbol.
Flow
Flow edge: DataNode def-use or dataflow relationship.
Implementations
Sourceimpl EdgeKind
impl EdgeKind
Sourcepub fn participates_in_scc(self) -> bool
pub fn participates_in_scc(self) -> bool
Returns true if this edge kind participates in SCC computation.
Sourcepub fn is_cross_file(self) -> bool
pub fn is_cross_file(self) -> bool
Returns true if this edge represents a cross-file dependency.