pub struct EdgeData {
pub kind: EdgeKind,
pub confidence: f32,
pub flow_kind: Option<FlowKind>,
}Expand description
Data stored for each edge in the graph.
Fields
kind: EdgeKindSemantic kind of the relationship.
confidence: f32Confidence level for the edge resolution. Used for cross-language and best-effort resolution.
flow_kind: Option<FlowKind>Flow kind for dataflow edges (None for non-Flow edges).
Implementations
Sourceimpl EdgeData
impl EdgeData
Sourcepub fn new(kind: EdgeKind) -> Self
pub fn new(kind: EdgeKind) -> Self
Creates a new edge with full confidence (1.0) and no flow kind.
Sourcepub fn with_confidence(kind: EdgeKind, confidence: f32) -> Self
pub fn with_confidence(kind: EdgeKind, confidence: f32) -> Self
Creates a new edge with specified confidence and no flow kind.
Sourcepub fn flow(flow_kind: FlowKind, confidence: f32) -> Self
pub fn flow(flow_kind: FlowKind, confidence: f32) -> Self
Creates a Flow edge with a flow kind and confidence.
pub fn participates_in_scc(&self) -> bool