#[non_exhaustive]pub enum NodeData {
File(FileNode),
Symbol(SymbolNode),
External(ExternalNode),
Data(DataGraphNode),
}Expand description
Unified node data enum for the dependency graph.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl NodeData
impl NodeData
Sourcepub fn as_symbol(&self) -> Option<&SymbolNode>
pub fn as_symbol(&self) -> Option<&SymbolNode>
Returns the SymbolId and associated data if this is a SymbolNode.
Sourcepub fn as_external(&self) -> Option<&ExternalNode>
pub fn as_external(&self) -> Option<&ExternalNode>
Returns the ExternalNode if this is an ExternalNode.
Sourcepub fn as_data(&self) -> Option<&DataGraphNode>
pub fn as_data(&self) -> Option<&DataGraphNode>
Returns the DataGraphNode if this is a Data node.
Sourcepub fn symbol_name(&self) -> Option<&str>
pub fn symbol_name(&self) -> Option<&str>
Returns the symbol name if this is a SymbolNode.