#[non_exhaustive]pub enum DefaultVisibility {
PublicByDefault,
PrivateByDefault,
}Expand description
Default visibility assumed when a symbol declares no explicit modifier.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PublicByDefault
When visibility is None, treat the symbol as public (Python, C functions).
PrivateByDefault
When visibility is None, treat the symbol as private (Rust, JS, TS, Go, C++).